StringReader

Struct StringReader 

pub(crate) struct StringReader<'input> {
    input: &'input str,
    total_length: usize,
    cursor: ReaderCursor,
}
Reads command input while exposing Brigadier-compatible UTF-16 positions.

Fields

input: &'input strtotal_length: usizecursor: ReaderCursor

Implementations

Source

impl<'input> StringReader<'input>

pub(crate) fn new(input: &'input str) -> Self

Creates a reader at the beginning of input.

pub(crate) const fn input(&self) -> &'input str

Returns the complete command input.

pub(crate) const fn total_length(&self) -> usize

Returns the input length in UTF-16 code units.

pub(crate) const fn cursor(&self) -> usize

Returns the current position in UTF-16 code units.

pub(crate) const fn byte_cursor(&self) -> usize

Returns the current position in UTF-8 bytes.

pub(crate) const fn remaining_length(&self) -> usize

Returns the remaining length in UTF-16 code units.

pub(crate) const fn can_read(&self) -> bool

Returns whether at least one character remains.

pub(crate) fn can_read_length(&self, length: usize) -> bool

Returns whether length UTF-16 code units remain.

pub(crate) fn peek(&self) -> Option<char>

Returns the next Unicode scalar without advancing the reader.

pub(crate) fn read(&mut self) -> Option<char>

Reads the next Unicode scalar.

pub(crate) fn skip(&mut self) -> bool

Advances past the next Unicode scalar if one remains.

pub(crate) fn read_so_far(&self) -> &'input str

Returns the input before the cursor.

pub(crate) fn remaining(&self) -> &'input str

Returns the input at and after the cursor.

pub(crate) fn read_remaining(&mut self) -> &'input str

Reads all remaining input.

pub(crate) fn advance_bytes(&mut self, bytes: usize) -> bool

Advances by an exact UTF-8 byte count while retaining Brigadier’s UTF-16 cursor.

pub(crate) fn skip_whitespace(&mut self)

Advances past whitespace recognized by Java’s Character.isWhitespace.

pub(crate) fn read_unquoted_string(&mut self) -> &'input str

Reads an unquoted Brigadier string.

pub(crate) fn read_unquoted_token(&mut self) -> &'input str

Reads one custom argument token up to Java-compatible whitespace.

pub(crate) fn read_quoted_string( &mut self, ) -> Result<String, CommandSyntaxError>

Reads a single- or double-quoted Brigadier string.

pub(crate) fn read_string(&mut self) -> Result<String, CommandSyntaxError>

Reads a quoted or unquoted Brigadier string.

pub(crate) fn read_int(&mut self) -> Result<i32, CommandSyntaxError>

Reads a signed 32-bit integer.

pub(crate) fn read_long(&mut self) -> Result<i64, CommandSyntaxError>

Reads a signed 64-bit integer.

pub(crate) fn read_double(&mut self) -> Result<f64, CommandSyntaxError>

Reads a 64-bit floating-point number.

pub(crate) fn read_float(&mut self) -> Result<f32, CommandSyntaxError>

Reads a 32-bit floating-point number.

pub(crate) fn read_boolean(&mut self) -> Result<bool, CommandSyntaxError>

Reads a lowercase Brigadier boolean.

pub(crate) fn expect( &mut self, expected: char, ) -> Result<(), CommandSyntaxError>

Consumes expected or returns a contextual syntax error.

pub(super) fn try_read_literal(&mut self, literal: &str) -> bool

fn read_string_until( &mut self, terminator: char, ) -> Result<String, CommandSyntaxError>

fn read_number<T>( &mut self, expected: CommandSyntaxErrorKind, invalid: fn(Box<str>) -> CommandSyntaxErrorKind, ) -> Result<T, CommandSyntaxError>
where T: FromStr,

pub(crate) const fn checkpoint(&self) -> ReaderCursor

Captures the current reader position for later restoration.

pub(crate) const fn restore(&mut self, checkpoint: ReaderCursor)

Restores a position previously returned by Self::checkpoint.

pub(crate) fn error(&self, kind: CommandSyntaxErrorKind) -> CommandSyntaxError

Creates a syntax error at the current reader position.

const fn is_allowed_number(character: char) -> bool

const fn is_quoted_string_start(character: char) -> bool

const fn is_allowed_in_unquoted_string(character: char) -> bool